// Google Maps オブジェクト
var googleMap;

// マーカーのカウント
var markerCount = 1;

// 成功時のコールバック関数
function geoSuccess(position) {

  // 取得した位置情報から LatLng オブジェクトを作成
  var latlng = new google.maps.LatLng(position.coords.latitude,
                                      position.coords.longitude);

  // マーカーを作成して追加
  var marker = new google.maps.Marker({
    position: latlng,
    map: googleMap,
    animation: google.maps.Animation.DROP,
    icon: 'http://gmaps-samples.googlecode.com/svn/trunk/markers/red/marker'
                                                      + markerCount + '.png'
  });

  // 新しく追加した位置にスクロール
  googleMap.panTo(latlng);

  // マーカーの値をインクリメント
  markerCount++;
}

// 失敗時のコールバック関数
function geoError(e) {
  var message;
  switch (e.code) {
    case e.PERMISSION_DENIED:
      message = '位置情報取得が許可されていません。';
      break;
    case e.POSITION_UNAVAILABLE:
      message = '位置情報が取得できませんでした。';
      break;
    case e.TIMEOUT:
      message = 'タイムアウトになりました。';
      break;
  }
  alert(message);
}

// watchId を定義
var watchId = null;

// ボタンのイベントを定義
var button = document.getElementById('start-btn');
button.addEventListener('click', function() {

  // watchId がある場合は clearWatch メソッドを実行
  if (watchId) {
    navigator.geolocation.clearWatch(watchId);
    button.innerHTML = 'start';
    watchId = null;
  }

  // watchPosition を実行して watchId を保持
  else {
    watchId = navigator.geolocation.watchPosition(geoSuccess, geoError);
    button.innerHTML = 'stop';
  }
}, false);

// Google Mapを描画
googleMap = new google.maps.Map(document.getElementById('map-canvas'), {
  zoom: 16,
  mapTypeId: google.maps.MapTypeId.ROADMAP
});
