// ページタイトルを書き換える
var pageTitle = document.getElementById('title').textContent;
document.title = pageTitle;

// 履歴情報が無い場合は置き換える
if (!history.state) {
  var pageId = document.getElementById('page').dataset.pageId;
  history.replaceState(pageId, pageTitle, null);
}

// A要素をクリックしたときにgetContents関数を実行する
document.addEventListener('click', function(e) {
  if (e.target.tagName === 'A') {
    // 本来のページ遷移を止める
    e.preventDefault();

    var href = e.target.getAttribute('href');

    // Stateオブジェクトを用意
    var pageState;
    if (href == '?page=a') {
      pageState = 'page-a';
    } else {
      pageState = 'page-b';
    }

    // Ajaxでコンテンツを読み込む
    getContents(href);

    // 履歴情報を追加し、URLを書き換える
    history.pushState(pageState, null, href);
  }
});

// 戻る、進むでURLが切り替わったときのイベント
window.addEventListener('popstate', function(e) {
  // 初回ページ読み込み時にも popstate イベントが呼ばれるが
  // e.state が null になっているので実行しない
  if (e.state !== null) {
    var href
    // Stateオブジェクトを見て取得するコンテンツのURLを決定
    if (e.state == 'page-a') {
      href = '?page=a';
    } else {
      href = '?page=b';
    }
    getContents(href);
  }
}, false);

// Ajaxでコンテンツを受け取り、表示を更新する関数
function getContents(href) {
  var xhr = new XMLHttpRequest();
  xhr.onreadystatechange = function() {
    if (xhr.readyState === 4 && xhr.status === 200) {
      // コンテンツが取得できたらHTML内に反映する
      document.getElementById('content').innerHTML = xhr.responseText;

      // ページタイトルを書き換える
      var pageTitle = document.getElementById('title').textContent;
      document.title = pageTitle;
    }
  };
  xhr.open('GET', href, false);

  // Ajaxでのリクエストを判別するためにヘッダーを付与する
  xhr.setRequestHeader('X-AJAX-REQUEST', 'true');
  xhr.send();
}
